acsch_vec

Function acsch_vec 

pub fn acsch_vec(x: &[f64]) -> Vec<f64>
acsch_vec(x)

Inverse Hyperbolic Function

The acsch_vec function calculates the inverse hyperbolic cosecant value of each element in the input vector, represented as a radian. The result is a new vector containing the arccsch values, which are the angles that correspond to the input values.

Examples

use mathlab::math::{acsch_vec, INF_F64 as inf};
assert_eq!(acsch_vec(&[0.0, 1.825305574687952, 0.086589537530047]), [inf, 0.523598775598299, 3.141592653589793]);

End Fun Doc