sin_vec

Function sin_vec 

pub fn sin_vec(x: &[f64]) -> Vec<f64>
sin_vec(x)

Trigonometric Function

The sin_vec function calculates the sine value of each angle represented as a radian in the input iterator, constructing a new vector from these results.

Examples

use mathlab::math::sin_vec;
assert_eq!(sin_vec(&[0.0, 1e-10, 0.5235987756]), [0.0, 1e-10, 0.5]);

End Fun Doc